@@ -10,7 +10,7 @@ from flask import request
 from flask_atomic.dao.buffer.data import DataBuffer
 from flask_atomic.dao.buffer.query import QueryBuffer
 from flask_atomic.dao.querystring import QueryStringProcessor
-from flask_atomic.httputils.exceptions import HTTPConflict
+from flask_atomic.http.exceptions import HTTPConflict
 
 
 class BaseDAO:
@@ -185,7 +185,6 @@ class BaseDAO:
     def create(self, payload):
         self.validate_arguments(payload)
         instance = self.model(**payload)
-        instance.id = None
         return DataBuffer(self.save(instance), instance.schema(), instance.fields(), False)
 
     def save(self, instance):
